﻿using FluentValidation.AspNetCore;
using Microsoft.AspNetCore.Mvc;
using Performance.DtoModels;
using Performance.Infrastructure;
using Performance.Services;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;

namespace Performance.Extract.Api.Controllers
{
    [Route("api/[controller]")]
    public class ModExtractController : Controller
    {
        private ModExtractService modExtractService;
        public ModExtractController(ModExtractService modExtractService)
        {
            this.modExtractService = modExtractService;
        }
        
        /// <summary>
        /// 绩效考核项费用来源
        /// </summary>
        /// <returns></returns>
        [Route("source")]
        [HttpPost]
        public ApiResponse FeeSource([FromBody]ModModuleRequest request)
        {
            if (request.HospitalId == null || request.HospitalId.Value == 0)
                return new ApiResponse(ResponseType.ParameterError, "HospitalId 参数错误！");

            LogHelper.Information($"绩效考核项费用来源：{JsonHelper.Serialize(request)}", "请求参数");
            var list = modExtractService.FeeSource(request);
            return new ApiResponse(ResponseType.OK, list);
        }

        /// <summary>
        /// 绩效收入模板配置项列表
        /// </summary>
        /// <returns></returns>
        [Route("items")]
        [HttpPost]
        public ApiResponse Items([FromBody]ModItemRequest request)
        {
            LogHelper.Information($"绩效收入模板配置项列表：{JsonHelper.Serialize(request)}", "请求参数");
            modExtractService.AddItems(request.ModuleId.Value);
            return new ApiResponse(ResponseType.OK);
        }
    }
}